.. role:: hidden
    :class: hidden-section


botorch.distributions
========================================================
.. automodule:: botorch.distributions
    :members:

Distributions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.distributions.distributions
    :members:
